/*
The sensor outputs provided by the library are the raw 16-bit values
obtained by concatenating the 8-bit high and low accelerometer and
magnetometer data registers. They can be converted to units of g and
gauss using the conversion factors specified in the datasheet for your
particular device and full scale setting (gain).

Example: An LSM303D gives a magnetometer X axis reading of 1982 with
its default full scale setting of +/- 4 gauss. The M_GN specification
in the LSM303D datasheet (page 10) states a conversion factor of 0.160
mgauss/LSB (least significant bit) at this FS setting, so the raw
reading of -1982 corresponds to 1982 * 0.160 = 317.1 mgauss =
0.3171 gauss.

In the LSM303DLHC, LSM303DLM, and LSM303DLH, the acceleration data
registers actually contain a left-aligned 12-bit number, so the lowest
4 bits are always 0, and the values should be shifted right by 4 bits
(divided by 16) to be consistent with the conversion factors specified
in the datasheets.

Example: An LSM303DLH gives an accelerometer Z axis reading of -16144
with its default full scale setting of +/- 2 g. Dropping the lowest 4
bits gives a 12-bit raw value of -1009. The LA_So specification in the
LSM303DLH datasheet (page 11) states a conversion factor of 1 mg/digit
at this FS setting, so the value of -1009 corresponds to -1009 * 1 =
1009 mg = 1.009 g.
*/

#include <SPI.h>
#include <Wire.h>
#include <LSM303.h>
#include <Adafruit_GFX.h>
#include <Adafruit_PCD8544.h>

// D4 - Serial clock out (CLK)
// D14 - Serial data out (DIN)
// D2 - Data/Command select (D/C)
// D15 - LCD chip select (CE)
// D16 - LCD reset (RST)
Adafruit_PCD8544 display = Adafruit_PCD8544(4, 14, 2, 15, 16);

LSM303 compass;

char report[80];
// Accelerometer Calibration{x,y,z}
long acmin[3] = {0, 0, 0};
long acmax[3] = {0, 0, 0};

void setup()
{
	Serial.begin(9600);
	Wire.begin();

	compass.init();
	compass.enableDefault();
	Serial.println(compass.getDeviceType()); //DLHC is 2
	display.begin();
	display.setContrast(60);	// Choose best contrast
	display.display(); 			// show splashscreen
	delay(20);
	display.clearDisplay();   	// clears the screen and buffer
}

void loop()
{
  compass.read();

  acmin[0] = min(acmin[0], compass.a.x);
  acmin[1] = min(acmin[1], compass.a.y);
  acmin[2] = min(acmin[2], compass.a.z);
  acmax[0] = max(acmax[0], compass.a.x);
  acmax[1] = max(acmax[1], compass.a.y);
  acmax[2] = max(acmax[2], compass.a.z);
  
	display.clearDisplay();
	display.setTextSize(1);
	display.setTextColor(BLACK);
	display.setCursor(0,0);
	display.println("min: ");
	display.print(acmin[0]);
	display.print(" ");
	display.print(acmin[1]);
	display.print(" ");
	display.println(acmin[2]);
	
	display.println("max: ");
	display.print(acmax[0]);
	display.print(" ");
	display.print(acmax[1]);
	display.print(" ");
	display.print(acmax[2]);
	display.display();

  delay(500);
}
